Module alloc

Module alloc 

Memory allocation.

Structs

AllocError
The AllocError error indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator.
Global
Default implementation of Allocator.

Traits

Allocator
Memory allocation.