Box

Struct Box 

pub struct Box<T: ?Sized, A: Allocator = Global> { /* private fields */ }
A pointer type that uniquely owns a heap allocation of type T.

Implementations

Source

impl<T> Box<T>

pub fn new(t: T) -> Self

Allocates memory on the heap and then places x into it.

use pstd::Box;
let b = Box::new(99);
assert_eq!( *b, 99 );
Source

impl<T, A: Allocator> Box<T, A>

pub fn new_in(t: T, a: A) -> Self

Allocates memory in the given allocator then places x into it.