BoxA

Struct BoxA 

pub struct BoxA<T: ?Sized, A: Allocator> { /* private fields */ }
A pointer type that uniquely owns a heap allocation of type T.

dyn values can be boxed using the unsize_box macro.

Implementations

Source

impl<T, A: Allocator> BoxA<T, A>

pub fn new(t: T) -> Self
where A: Default,

Allocates memory then places t into it.

pub fn new_in(t: T, a: A) -> Self

Allocates memory in the given allocator then places t into it.

pub fn from_slice_in(s: &[T], a: A) -> BoxA<[T], A>
where T: Clone,

Allocates memory in the given allocator then clones s into it.

Source

impl<T: ?Sized, A: Allocator> BoxA<T, A>

pub fn from_str(s: &str) -> BoxA<str, A>
where A: Default,

Allocates memory then copies s into it.

pub fn from_str_in(s: &str, a: A) -> BoxA<str, A>

Allocates memory in the given allocator then copies s into it.

Note: there is currently no equivalent in the standard library.

pub fn into_raw_with_allocator(b: Self) -> (*mut T, A)

Convert into raw pointer and allocator.

pub unsafe fn from_raw_in(p: *mut T, a: A) -> Self

Create from raw pointer in specified allocator.

Safety

This function is unsafe because improper use may lead to memory problems. For example, a double-free may occur if the function is called twice on the same raw pointer.

The non-null pointer must point to a block of memory allocated by a.