Module collections

Module collections 

Containers: BTreeMap, BTreeSet, HashMap and HashSet.

Re-exports

pub use btree_map::BTreeMap;
pub use btree_map::BTreeMapA;
pub use btree_set::BTreeSet;
pub use btree_set::BTreeSetA;

Modules

btree_map
BTreeMap similar to std::collections::BTreeMap.
btree_set
BTreeSet similar to std::collections::BTreeSet.
hash_map
Hashmap.
hash_set
Hashset.

Structs

DefaultHashBuilder
Default hash builder for the S type parameter of HashMap and HashSet.
HashMap
A hash map implemented with quadratic probing and SIMD lookup.
HashSet
A hash set implemented as a HashMap where the value is ().
TryReserveError
The error type for try_reserve methods.

Enums

TryReserveErrorKind
Details of the allocation that caused a TryReserveError