CustomTuning

Struct CustomTuning 

pub struct CustomTuning<AL: Allocator + Clone = Global> { /* private fields */ }
Implementation of Tuning. Default branch is 64, default allocation unit is 16.

Implementations

Source

impl<AL: Allocator + Clone> CustomTuning<AL>

pub fn new(branch: u16, alloc_unit: u16) -> Self
where AL: Default,

Construct with specified branch and allocation unit.

pub const fn new_in(branch: u16, alloc_unit: u16, alloc: AL) -> Self

Construct with specified branch, allocation unit and allocator.

The minimum branch is 6. A small branch is faster for insertion but slower for retrieval.

A small alloc_unit is slower for insertion but uses less memory.

pub const fn new_in_def(alloc: AL) -> Self

Construct with specified allocator and default branch and allocation unit (currently 64,16).