Vec similar to std::vec::Vec.
Known differences : element drop order, leak after panic in drop (also applies to BTreeMap/BTreeSet).
Not possible under stable Rust: VecA::const_make_global.
Structs
- Drain
- An iterator to remove a range.
- Extract
If - An iterator which uses a closure to determine if an element should be removed.
- Into
Iter - Consuming iterator for
Vec. - PeekMut
- Structure wrapping a mutable reference to the last item in a
Vec. - Splice
- A splicing iterator for
Vec. - VecA
- A vector that grows as elements are pushed onto it.
Type Aliases
- Vec
- A vector that grows as elements are pushed onto it similar to similar to
std::vec::Vec.