Memory allocation.
Structs
- Alloc
Error - The
AllocErrorerror indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator. - Global
- Default implementation of Allocator.
Traits
- Allocator
- Memory allocation.