pub struct BoxA<T: ?Sized, A: Allocator> { /* private fields */ }Expand description
A pointer type that uniquely owns a heap allocation of type T.
dyn values can be boxed using the unsize_box macro.
Implementations
Sourceimpl<T, A: Allocator> BoxA<T, A>
impl<T, A: Allocator> BoxA<T, A>
Sourceimpl<T: ?Sized, A: Allocator> BoxA<T, A>
impl<T: ?Sized, A: Allocator> BoxA<T, A>
Sourcepub fn from_str(s: &str) -> BoxA<str, A>where
A: Default,
pub fn from_str(s: &str) -> BoxA<str, A>where
A: Default,
Allocates memory then copies s into it.
Sourcepub fn from_str_in(s: &str, a: A) -> BoxA<str, A>
pub fn from_str_in(s: &str, a: A) -> BoxA<str, A>
Allocates memory in the given allocator then copies s into it.
Note: there is currently no equivalent in the standard library.
Sourcepub fn into_raw_with_allocator(b: Self) -> (*mut T, A)
pub fn into_raw_with_allocator(b: Self) -> (*mut T, A)
Convert into raw pointer and allocator.
Sourcepub unsafe fn from_raw_in(p: *mut T, a: A) -> Self
pub unsafe fn from_raw_in(p: *mut T, a: A) -> Self
Create from raw pointer in specified allocator.
Safety
This function is unsafe because improper use may lead to memory problems. For example, a double-free may occur if the function is called twice on the same raw pointer.
The non-null pointer must point to a block of memory allocated by a.