pub struct CustomTuning<AL: Allocator + Clone = Global> { /* private fields */ }Expand description
Implementation of Tuning. Default branch is 64, default allocation unit is 16.
Implementations
Sourceimpl<AL: Allocator + Clone> CustomTuning<AL>
impl<AL: Allocator + Clone> CustomTuning<AL>
Sourcepub fn new(branch: u16, alloc_unit: u16) -> Selfwhere
AL: Default,
pub fn new(branch: u16, alloc_unit: u16) -> Selfwhere
AL: Default,
Construct with specified branch and allocation unit.
Sourcepub const fn new_in(branch: u16, alloc_unit: u16, alloc: AL) -> Self
pub const fn new_in(branch: u16, alloc_unit: u16, alloc: AL) -> Self
Construct with specified branch, allocation unit and allocator.
The minimum branch is 6. A small branch is faster for insertion but slower for retrieval.
A small alloc_unit is slower for insertion but uses less memory.
Sourcepub const fn new_in_def(alloc: AL) -> Self
pub const fn new_in_def(alloc: AL) -> Self
Construct with specified allocator and default branch and allocation unit (currently 64,16).