Module vec

Module vec 

Vec similar to std::vec::Vec.

Known differences : element drop order, leak after panic in drop (also applies to BTreeMap/BTreeSet).

Not possible under stable Rust: Vec::const_make_global.

Structs

Drain
An iterator to remove a range.
ExtractIf
An iterator which uses a closure to determine if an element should be removed.
IntoIter
Consuming iterator for Vec.
PeekMut
Structure wrapping a mutable reference to the last item in a Vec.
Splice
A splicing iterator for Vec.
Vec
A vector that grows as elements are pushed onto it similar to similar to std::vec::Vec.