Module vec

Module vec 

vec::Vec similar to std::vec::Vec, not yet well tested. Not possible under stable Rust: Vec::const_make_global, Vec::into_boxed_slice (?)

ToDo : peek_mut (may not do that one), various trait impls.

Ideas : have features which allow exclusion of unstable features, methods which can panic.

What about more non-panic methods: try_insert, index, index_mut

Structs

Drain
An iterator to remove a range.
ExtractIf
An iterator which uses a closure to determine if an element should be removed.
IntoIter
Consuming iterator for Vec.
Splice
A splicing iterator for Vec.
Vec
A vector that grows as elements are pushed onto it similar to similar to std::vec::Vec.